entities/adapters.py
changeset 10732 6231587fcfc5
parent 10731 0736e31f8644
child 10973 0939ad2edf63
--- a/entities/adapters.py	Tue Sep 22 15:31:44 2015 +0200
+++ b/entities/adapters.py	Tue Oct 13 18:20:42 2015 +0200
@@ -171,19 +171,21 @@
     __abstract__ = True
 
     def download_url(self, **kwargs): # XXX not really part of this interface
-        """return a URL to download entity's content"""
+        """return a URL to download entity's content
+
+        It should be a unicode object containing url-encoded ASCII."""
         raise NotImplementedError
 
     def download_content_type(self):
         """return MIME type of the downloadable content"""
         raise NotImplementedError
 
     def download_encoding(self):
         """return encoding of the downloadable content"""
         raise NotImplementedError
 
     def download_file_name(self):
         """return file name of the downloadable content"""
         raise NotImplementedError
 
     def download_data(self):
@@ -171,19 +171,21 @@
 
     def download_content_type(self):
-        """return MIME type of the downloadable content"""
+        """return MIME type (unicode) of the downloadable content"""
         raise NotImplementedError
 
@@ -171,19 +171,21 @@
 
     def download_encoding(self):
-        """return encoding of the downloadable content"""
+        """return encoding (unicode) of the downloadable content"""
         raise NotImplementedError
 
@@ -171,19 +171,21 @@
 
     def download_file_name(self):
-        """return file name of the downloadable content"""
+        """return file name (unicode) of the downloadable content"""
         raise NotImplementedError
 